agentle.mcp.models.annotations
==============================

.. automodule:: agentle.mcp.models.annotations

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Annotations
      BaseModel
      ConfigDict
      Sequence
   